@@ -1,6 +1,6 @@
 package Module::Implementation;
 {
-  $Module::Implementation::VERSION = '0.02';
+  $Module::Implementation::VERSION = '0.03';
 }
 
 use strict;
@@ -45,7 +45,7 @@ sub _build_loader {
             *{ $package . '::_implementation' } = $impl_sub;
         }
 
-        return;
+        return $loaded;
     };
 }
 
@@ -139,7 +139,7 @@ Module::Implementation - Loads one of several alternate underlying implementatio
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -209,8 +209,6 @@ I recommend that you I<do not> call this loader in an C<import()> sub. If a
 caller explicitly requests no imports, your C<import()> sub will not be run at
 all, which can cause weird breakage.
 
-Instead, I recommend calling this loader in a C<BEGIN> block like you see above.
-
 =head1 HOW THE IMPLEMENTATION LOADER WORKS
 
 The implementation loader works like this ...
@@ -250,6 +248,8 @@ If an implementation is loaded successfully, the loader creates an
 C<_implementation()> subroutine in the package that created the loader. This
 lets you introspect the implementation for tests and other internal use.
 
+The loader returns the name of the package it loaded.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
